# jsonistyping

**jsonistyping** is a limple and lightweight type checking and type conversion library without any 3rd party dependencies. It was designed to be used in the various APIs and flask-like frameworks.